@@ -17,14 +17,14 @@ setMethod("tax2traits", signature(object="taxlist"),
 					TaxonConceptID=object@taxonRelations$TaxonConceptID,
 					stringsAsFactors=FALSE)
 			# first entry with concepts at level
-			for(i in paste(levels(object))) {
+			for(i in levels(object)) {
 				ID <- object@taxonRelations[
 						paste(object@taxonRelations$Level) == i,
 						"TaxonConceptID"]
 				TAX[,i] <- ID[match(object@taxonRelations$TaxonConceptID, ID)]
 			}
 			# second entry parents
-			for(i in paste(levels(object))[-length(levels(object))]) {
+			for(i in levels(object)[-length(levels(object))]) {
 				if(!all(is.na(TAX[,i])) & !all(!is.na(TAX[,i]))) {
 					TAX <- split(TAX, is.na(TAX[,i]))
 					ID <- TAX[["FALSE"]][,i]
@@ -60,7 +60,9 @@ setMethod("tax2traits", signature(object="taxlist"),
 					}
 				}
 			}
-			object <- add_trait(object, TAX)
+			colnames(TAX)[colnames(TAX) == "TaxonConceptID"] <- "ConceptID"
+			object <- do.call(update_trait, c(list(taxlist=object),
+							as.list(TAX)))
 			if(get_names) {
 				Names <- accepted_name(object)
 				for(i in paste(levels(object))) {
